#!/bin/sh
#
# Dieses Skript extrahiert aus den $LOGS einige Interessante
# Fakten zu Online-Aktivitaeten der letzten 5 Wochen
#
# Author: Martin Bock <martin@martin-bock.de>
# Date:   17-Jun-2000

# Einige globale Variablen
#
LOGS="/var/log/messages*"
MONTH=$(date +%b)
CURRENT=$(zgrep "Connect time" $LOGS | grep $MONTH | sort)

# Das Datum der aeltesten Verbindung
#
LAST=$(zgrep "Connect time" $LOGS | \
	grep $MONTH |\
	sort | \
	head -1 | \
	tr -s ' ' | \
	cut -d" " -f1-3 |\
	cut -d":" -f2-4)

# Das Datum der juengsten Verbindung
#
FIRST=$(zgrep "Connect time" $LOGS | \
	grep $MONTH |\
	sort | \
	tail -1 | \
	tr -s ' ' | \
	cut -d" " -f1-3 |\
	cut -d":" -f2-4)

# Die Anzahl der Verbindungen
#
CONNECTS=$(zgrep "Connect time" $LOGS | grep -c $MONTH)

#
# Die Gesamtdauer der Verbindungen
#
DAUER=$(zgrep "Connect time" $LOGS | grep $MONTH |\
	awk '{ t+=$8 } END { printf("%d\n", t) }')

# T-Onlinekosten:
# DM 29,00 fuer erste 30 Stunden (1800 Minuten)
# DM 0,03 fuer jede weitere Minute
#
if [ $DAUER -lt 1800 ]
then
    KOSTEN="29.00"
    MESG_SUM=$(expr 1800 - $DAUER)
    MESG="Du hast $MESG_SUM Online-Minuten verschenkt!"
else
    KOSTEN=$(zgrep "Connect time" $LOGS | grep $MONTH |\
	    awk '{ t+=$8 } END { printf("%3.2f\n", (t-1800)*0.03+29) }')
    MESG_SUM=$(expr $DAUER - 1800)
    MESG="Du hast $MESG_SUM Online-Minuten ueberzogen!"
fi

# Die Ausgabe
#
echo -e "\n---------------------------------------------------------------"
echo "PPP-Verbindungstatistik vom $LAST bis $FIRST" 
echo "---------------------------------------------------------------"
echo -e "Gesamtzzahl:\t$CONNECTS Stueck"
echo -e "Gesamtdauer:\t$DAUER Minuten"
echo -e "Gesamtkosten:\t$KOSTEN DM"
echo -e "\n$MESG"
